@@ -150,11 +150,14 @@ def fprint(*args:Any, nl:bool=True, flush:bool=False, do_print:bool=True, end:Op
         if not args:
             print('')
 
-        for arg in args:
-            if nl:
-                arg = f'{arg}\n'
+        for arg_indx, arg in enumerate(args):
+            if arg_indx == len(args)-1:
+                print(arg, end=end, flush=flush)
+            else:
+                print(arg, end=' ', flush=flush)
 
-            print(arg, end=end, flush=flush)
+        if nl and not end:
+            print()
 
 
 def finput(text:str='', nl:bool=True, use_suffix:bool=True, ret_type:type=str):
@@ -344,6 +347,7 @@ def write_file(text:Any, file_path:str, append:bool=False, create:bool=True, enc
 
     with open(file_path, mode=mode, encoding=encoding) as f:
         f.write(text + '\n')
+        fprint(f'Content written to file: {file_path}', do_print=do_print)
 
     return did_create
 
@@ -506,6 +510,10 @@ def chunker(seq, size:int) -> Any:
     return [seq[pos:pos + size] for pos in range(0, len(seq), size)]
 
 
+def flatten_list(lst:list[Any]) -> Any:
+    return [item for sublist in lst for item in sublist]
+
+
 def create_json(filepath:str, force:bool=False, do_print:bool=True) -> bool:
     """Create a new empty JSON file.
     
